Welcome to ClientVPS Mirrors

Help for package con2lki
Type: Package
Title: Calculate the Dutch Air Quality Index (LKI)
Version: 0.1.0
Author: Mark Baas
Maintainer: Mark Baas <mark.baas@gmail.com>
Description: Calculates the dutch air quality index (LKI). This index was created on the basis of scientific studies of the health effects of air pollution. From these studies it can be deduced at what concentrations a certain percentage of the population can be affected. For more information see: https://www.rivm.nl/bibliotheek/rapporten/2014-0050.pdf.
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.1.1
Suggests: testthat, dplyr
NeedsCompilation: no
Packaged: 2021-01-26 09:04:09 UTC; mark
Repository: CRAN
Date/Publication: 2021-01-29 10:00:06 UTC

Calculate lki from contaminants

Description

LKI is the air quality index used by the Netherlands. The index summarises data on air quality. Each substance concentration is converted into a number from 1 (little pollution) to 11 (a lot of pollution). The substance with the hight index value determines to whole air quality index. If all substances have the same index value, the total index value will be one point higher.

Usage

con2lki(no2, pm25, pm10, o3)

Arguments

no2

A vector of no2 values

pm25

A vector of pm25 values

pm10

A vector of pm10 values

o3

A vector of o3 values

Details

This index was created on the basis of scientific studies of the health effects of air pollution. From these studies it can be deduced at what concentrations a certain percentage of the population can be affected. For more information see: https://www.rivm.nl/bibliotheek/rapporten/2014-0050.pdf

Value

A vector of lki values

Examples

library(dplyr)

df <- data.frame(
    no2  = c(15, 30, 100,  1, 201),
    o3   = c(35, 20,  58,  0, 201),
    pm10 = c(4,  30, 101,  0, 101),
    pm25 = c(45, 40,  99,  2, 110)
)

df %>% mutate(
    lki = con2lki(no2, pm25, pm10, o3)
)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.